==> Heinzelmann-7.19.003-PHP8.zip: Quellcode/legacy/modules/customstatus/locales/en.php <==
<?php

$__LANG['Benutzerdefinierte Ticketstatus'] = 'User-defined ticket statuses';
$__LANG['Einträge gefunden'] = 'Entries found';
$__LANG['Status hinzufügen'] = 'Add status';
$__LANG['Technischer Name'] = 'Technical name';
$__LANG['Deutsch'] = 'German';
$__LANG['Englisch'] = 'English';
$__LANG['Status wird verwendet'] = 'Status is used';
$__LANG['Status löschen'] = 'Delete status';
$__LANG['Zeige _MENU_ Einträge'] = 'Show _MENU_ entries';
$__LANG['Keine Einträge gefunden'] = 'No entries found';
$__LANG['Eintrag _START_ bis _END_ (von _TOTAL_)'] = 'Entry _START_ to _END_ (from _TOTAL_)';
$__LANG['Diesen Status wirklich löschen?'] = 'Really delete this status?';
$__LANG['Beide Sprachfelder müssen ausgefüllt sein.'] = 'Both language fields must be filled in.';
$__LANG['Die Bezeichnungen dürfen maximal 50 Zeichen lang sein.'] = 'The names may be a maximum of 50 characters long.';
$__LANG['Der technische Name darf nur Großbuchstaben, Zahlen und Unterstriche enthalten.'] = 'The technical name may only contain capital letters, numbers and underscores.';
$__LANG['Ein Status mit dieser technischen Bezeichnung existiert bereits.'] = 'A status with this technical name already exists.';
$__LANG['Es können nur benutzerdefinierte Status bearbeitet werden.'] = 'Only user-defined statuses can be edited.';
$__LANG['Systemstatus können nicht geändert werden.'] = 'System statuses cannot be changed.';
$__LANG['Der neue Status wurde angelegt'] = 'The new status has been created';
$__LANG['Nur benutzerdefinierte Status können gelöscht werden.'] = 'Only user-defined statuses can be deleted.';
$__LANG['Dieser Status ist noch Tickets zugewiesen und kann nicht gelöscht werden.'] = 'This status is still assigned to tickets and cannot be deleted.';

==> Heinzelmann-7.23.001-PHP8.zip: Quellcode/legacy/modules/customstatus/locales/en.php <==
<?php

$__LANG['Benutzerdefinierte Ticketstatus'] = 'User-defined ticket statuses';
$__LANG['Einträge gefunden'] = 'Entries found';
$__LANG['Status hinzufügen'] = 'Add status';
$__LANG['Technischer Name'] = 'Technical name';
$__LANG['Deutsch'] = 'German';
$__LANG['Englisch'] = 'English';
$__LANG['Status wird verwendet'] = 'Status is used';
$__LANG['Status löschen'] = 'Delete status';
$__LANG['Zeige _MENU_ Einträge'] = 'Show _MENU_ entries';
$__LANG['Keine Einträge gefunden'] = 'No entries found';
$__LANG['Eintrag _START_ bis _END_ (von _TOTAL_)'] = 'Entry _START_ to _END_ (from _TOTAL_)';
$__LANG['Diesen Status wirklich löschen?'] = 'Really delete this status?';
$__LANG['Beide Sprachfelder müssen ausgefüllt sein.'] = 'Both language fields must be filled in.';
$__LANG['Die Bezeichnungen dürfen maximal 50 Zeichen lang sein.'] = 'The names may be a maximum of 50 characters long.';
$__LANG['Der technische Name darf nur Großbuchstaben, Zahlen und Unterstriche enthalten.'] = 'The technical name may only contain capital letters, numbers and underscores.';
$__LANG['Ein Status mit dieser technischen Bezeichnung existiert bereits.'] = 'A status with this technical name already exists.';
$__LANG['Es können nur benutzerdefinierte Status bearbeitet werden.'] = 'Only user-defined statuses can be edited.';
$__LANG['Systemstatus können nicht geändert werden.'] = 'System statuses cannot be changed.';
$__LANG['Der neue Status wurde angelegt'] = 'The new status has been created';
$__LANG['Nur benutzerdefinierte Status können gelöscht werden.'] = 'Only user-defined statuses can be deleted.';
$__LANG['Dieser Status ist noch Tickets zugewiesen und kann nicht gelöscht werden.'] = 'This status is still assigned to tickets and cannot be deleted.';

$__LANG['Ticketstatus & Auswirkungsgrad'] = 'Ticket status & impact level';
$__LANG['Benutzerdefinierte Dringlichkeits-Stufen'] = 'Custom urgency levels';
$__LANG['Dringlichkeit hinzufügen'] = 'Add urgency';
$__LANG['Eintrag wird verwendet'] = 'Entry is being used';
$__LANG['Eintrag löschen'] = 'Delete entry';
$__LANG['Benutzerdefinierte Auswirkungs-Stufen'] = 'Custom impact levels';
$__LANG['Auswirkung hinzufügen'] = 'Add impact';
$__LANG['- gefiltert aus _MAX_ Einträgen'] = '- filtered from _MAX_ entries';
$__LANG['Diesen Eintrag wirklich löschen?'] = 'Are you sure you want to delete this entry?';
$__LANG['Score muss zwischen 1 und 10 liegen.'] = 'Score must be between 1 and 10.';
$__LANG['Eintrag nicht gefunden.'] = 'Entry not found.';
$__LANG['Die Auswirkungsstufe wurde gespeichert.'] = 'The impact level has been saved.';
$__LANG['Die Dringlichkeitsstufe wurde gespeichert.'] = 'The urgency level has been saved.';
